@@ -41,6 +41,8 @@
 
 #define BUFFER_VA_LEN 200
 
+#define TO_HEX(c) (c>9? c+'a'-10 : c+'0')
+
 ret_t
 cherokee_buffer_new  (cherokee_buffer_t **buf)
 {
@@ -719,15 +721,21 @@ cherokee_buffer_encode_md5_digest (cherokee_buffer_t *buf)
 	int i;
 	struct MD5Context context;
 	unsigned char digest[16];
-
+	
 	MD5Init (&context);
-	MD5Update (&context, buf->buf, buf->len);
+	MD5Update (&context, (md5byte *)buf->buf, buf->len);
 	MD5Final (digest, &context);
 
 	cherokee_buffer_ensure_size (buf, 34);
 
 	for (i=0; i<16; i++) {
-		sprintf (buf->buf+(i*2), "%02x", digest[i]);
+		int tmp;
+
+		tmp = (digest[i] >> 4) & 0xf;
+		buf->buf[i*2] = TO_HEX(tmp);
+
+		tmp = digest[i] & 0xf;
+		buf->buf[(i*2)+1] = TO_HEX(tmp);
 	}
 	buf->buf[32] = '\0';
 	buf->len = 32;
@@ -762,7 +770,7 @@ cherokee_buffer_encode_md5 (cherokee_buffer_t *buf, cherokee_buffer_t *salt, che
 		sa++;
 
 	MD5Init (&context);
-	MD5Update (&context, buf->buf, buf->len);
+	MD5Update (&context, (md5byte *)buf->buf, buf->len);
 
 	return ret_ok;
 }
