@@ -41,6 +41,7 @@ typedef enum {
 } cherokee_boolean_t;
 
 typedef enum {
+	ret_no_sys          = -4,
 	ret_nomem           = -3, 
 	ret_deny            = -2, 
 	ret_error           = -1,
@@ -54,7 +55,7 @@ typedef enum {
 } ret_t;
 
 typedef unsigned int crc_t;
-
+typedef unsigned int cuint_t;
 
 CHEROKEE_END_DECLS
 
