@@ -218,7 +218,6 @@ cherokee_connection_clean (cherokee_connection_t *cnt)
 	cnt->post_len          = 0;
 	cnt->mmaped            = NULL;
 	cnt->mmap_entry_ref    = NULL;
-	cnt->extra_polling_fd  = -1;
 	cnt->rx                = 0;	
 	cnt->tx                = 0;
 	cnt->traffic_next      = 0;
@@ -243,6 +242,11 @@ cherokee_connection_clean (cherokee_connection_t *cnt)
 		cnt->post = NULL;
 	}
 
+	if (cnt->extra_polling_fd != -1) {
+		close (cnt->extra_polling_fd);
+		cnt->extra_polling_fd = -1;
+	}
+
 	cherokee_buffer_clean (cnt->request);
 	cherokee_buffer_escape_clean (cnt->request_escape);
 	cherokee_buffer_escape_set_ref (cnt->request_escape, cnt->request);
@@ -821,13 +825,6 @@ cherokee_connection_send (cherokee_connection_t *cnt)
 }
 
 
-ret_t
-cherokee_connection_close (cherokee_connection_t *cnt)
-{
-	return cherokee_socket_close (cnt->socket);
-}
-
-
 ret_t 
 cherokee_connection_pre_lingering_close (cherokee_connection_t *cnt)
 {
@@ -1004,16 +1001,21 @@ error:
 
 static ret_t
 get_authorization (cherokee_connection_t *cnt,
-		   char                  *ptr)
+		   cherokee_http_auth_t   type,
+		   char                  *ptr,
+	           int                    ptr_len)
 {
 	cherokee_buffer_t *auth = NULL;
 
 	if (strncasecmp(ptr, "Basic ", 6) == 0) {
 		char *end;
 
-		/* Set the type
-		 */
-		cnt->auth_type |= http_auth_basic;
+		/* Check the authentication type
+ 		 */
+		if (!(type & http_auth_basic))
+			return ret_error;
+
+		cnt->auth_type = http_auth_basic;
 
 		/* Get the rest of the data
 		 */
@@ -1037,11 +1039,14 @@ get_authorization (cherokee_connection_t *cnt,
 
 	} else if (strncasecmp(ptr, "Digest ", 7) == 0) {
 
-		/* Set the type
+		/* Check the authentication type
 		 */
-		cnt->auth_type |= http_auth_digest;
+		if (!(type & http_auth_digest))
+			return ret_error;
 
-		PRINT_ERROR_S ("TODO: unimplemented\n");
+		cnt->auth_type = http_auth_digest;
+
+		PRINT_ERROR_S ("TODO: To be unimplemented..\n");
 		return ret_error;
 
 	} else {
@@ -1461,7 +1466,6 @@ cherokee_connection_get_plugin_entry (cherokee_connection_t *cnt, cherokee_handl
 	/* Set the refereces
 	 */
 	cnt->realm_ref = (*plugin_entry)->auth_realm;
-	cnt->auth_type = (*plugin_entry)->authentication;
 
 	return ret_ok;
 }
@@ -1470,43 +1474,46 @@ cherokee_connection_get_plugin_entry (cherokee_connection_t *cnt, cherokee_handl
 ret_t 
 cherokee_connection_check_authentication (cherokee_connection_t *cnt, cherokee_handler_table_entry_t *plugin_entry)
 {
-	if (plugin_entry->validator_new_func != NULL) {
-		ret_t ret;
-		char *ptr;
-		int   len;
-		cherokee_validator_t *validator = NULL;
+	ret_t ret;
+	char *ptr;
+	int   len;
+	cherokee_validator_t *validator = NULL;
 
-		/* Look for authentication in the headers:
-		 * It's done on demand because the directory maybe don't have protection
-		 */
-		ret = cherokee_header_get_unknown (cnt->header, "Authorization", 13, &ptr, &len);
-		if (ret != ret_ok) {
-			goto unauthorized;
-		}
+	/* Return, there is nothing to do here
+	 */
+	if (plugin_entry->validator_new_func == NULL) 
+		return ret_ok;
 
-		ret = get_authorization (cnt, ptr);
-		if (ret != ret_ok) {
-			goto unauthorized;
-		}
-		
-		/* Create the validator object
-		 */
-		ret = plugin_entry->validator_new_func ((void **)&validator, 
-							plugin_entry->properties);
-		if (ret != ret_ok) {
-			cnt->error_code = http_internal_error;
-			return ret_error;	
-		}
-
-		/* Check the login/password
-		 */
-		ret = cherokee_validator_check (validator, cnt);
-		cherokee_validator_free (validator);
-
-		if (ret != ret_ok) {
-			goto unauthorized;
-		}
-       	}
+	/* Look for authentication in the headers:
+	 * It's done on demand because the directory maybe don't have protection
+	 */
+	ret = cherokee_header_get_unknown (cnt->header, "Authorization", 13, &ptr, &len);
+	if (ret != ret_ok) {
+		goto unauthorized;
+	}
+	
+	ret = get_authorization (cnt, plugin_entry->authentication, ptr, len);
+	if (ret != ret_ok) {
+		goto unauthorized;
+	}
+	
+	/* Create the validator object
+	 */
+	ret = plugin_entry->validator_new_func ((void **)&validator, 
+						plugin_entry->properties);
+	if (ret != ret_ok) {
+		cnt->error_code = http_internal_error;
+		return ret_error;	
+	}
+	
+	/* Check the login/password
+	 */
+	ret = cherokee_validator_check (validator, cnt);
+	cherokee_validator_free (validator);
+	
+	if (ret != ret_ok) {
+		goto unauthorized;
+	}
 
 	return ret_ok;
 
