@@ -41,24 +41,41 @@
 
 
 ret_t 
-cherokee_downloader_new (cherokee_downloader_t **downloader, cherokee_fdpoll_t *fdpoll)
+cherokee_downloader_new (cherokee_downloader_t **downloader)
+{
+	ret_t ret;
+	CHEROKEE_NEW_STRUCT(n, downloader);
+
+	/* Init
+	 */
+	ret = cherokee_downloader_init (n);
+	if (unlikely(ret != ret_ok)) return ret;
+
+	/* Return the object
+	 */
+	*downloader = n;
+	return ret_ok;
+}
+
+
+ret_t 
+cherokee_downloader_init (cherokee_downloader_t *n)
 {
 	int   i;
 	ret_t ret;
-	CHEROKEE_NEW_STRUCT(n, downloader);
 
 	/* Build
 	 */
 	ret = cherokee_request_header_new (&n->request);
 	if (unlikely(ret != ret_ok)) return ret;
 
-	ret = cherokee_buffer_new (&n->request_header);
+	ret = cherokee_buffer_init (&n->request_header);
 	if (unlikely(ret != ret_ok)) return ret;
 
-	ret = cherokee_buffer_new (&n->reply_header);
+	ret = cherokee_buffer_init (&n->reply_header);
 	if (unlikely(ret != ret_ok)) return ret;	
 
-	ret = cherokee_buffer_new (&n->body);
+	ret = cherokee_buffer_init (&n->body);
 	if (unlikely(ret != ret_ok)) return ret;		
 
 	ret = cherokee_socket_new (&n->socket);
@@ -81,7 +98,7 @@ cherokee_downloader_new (cherokee_downloader_t **downloader, cherokee_fdpoll_t *
 
 	/* Init the properties
 	 */
-	n->fdpoll = fdpoll;
+	n->fdpoll = NULL;
 	n->phase  = downloader_phase_init;
 
 	/* Lengths
@@ -95,15 +112,22 @@ cherokee_downloader_new (cherokee_downloader_t **downloader, cherokee_fdpoll_t *
 	n->info.post_sent    = 0;
 	n->info.body_recv    = 0;
 
-	/* Return the object
-	 */
-	*downloader = n;
 	return ret_ok;
 }
 
 
 ret_t 
 cherokee_downloader_free (cherokee_downloader_t *downloader)
+{
+	cherokee_downloader_mrproper (downloader);
+
+	free (downloader);
+	return ret_ok;
+}
+
+
+ret_t 
+cherokee_downloader_mrproper (cherokee_downloader_t *downloader)
 {
 	/* Remove the socket from the poll
 	 */
@@ -112,19 +136,30 @@ cherokee_downloader_free (cherokee_downloader_t *downloader)
 	/* Free the memory
 	 */
 	cherokee_request_header_free (downloader->request);
-	cherokee_buffer_free (downloader->request_header);
-	cherokee_buffer_free (downloader->reply_header);
-	cherokee_buffer_free (downloader->body);
+	cherokee_buffer_mrproper (&downloader->request_header);
+	cherokee_buffer_mrproper (&downloader->reply_header);
+	cherokee_buffer_mrproper (&downloader->body);
 	cherokee_socket_free (downloader->socket);
 	cherokee_header_free (downloader->header);
 
-	free (downloader);
 	return ret_ok;
 }
 
 
 ret_t 
-cherokee_downloader_set (cherokee_downloader_t *downloader, cherokee_buffer_t *url_string)
+cherokee_downloader_set_fdpoll (cherokee_downloader_t *downloader, cherokee_fdpoll_t *fdpoll)
+{
+	if (downloader->fdpoll != NULL) {
+		PRINT_ERROR_S ("ERROR: fdpoll already set\n");
+	}
+
+	downloader->fdpoll = fdpoll;
+	return ret_ok;
+}
+
+
+ret_t 
+cherokee_downloader_set_url (cherokee_downloader_t *downloader, cherokee_buffer_t *url_string)
 {
 	ret_t           ret;
 	cherokee_url_t *url;
@@ -138,7 +173,7 @@ cherokee_downloader_set (cherokee_downloader_t *downloader, cherokee_buffer_t *u
 
 	/* Build the request header
 	 */
-	ret = cherokee_request_header_build_string (downloader->request, downloader->request_header);
+	ret = cherokee_request_header_build_string (downloader->request, &downloader->request_header);
 	if (unlikely(ret < ret_ok)) return ret;
 
 	return ret_ok;
@@ -158,7 +193,7 @@ downloader_init (cherokee_downloader_t *downloader)
 
 	/* Check if there is a URL string..
 	 */
-	if (cherokee_buffer_is_empty (downloader->request_header)) {
+	if (cherokee_buffer_is_empty (&downloader->request_header)) {
 		return ret_error;
 	}
 
@@ -221,13 +256,13 @@ downloader_header_send (cherokee_downloader_t *downloader)
 
 	sock = downloader->socket;
 	
-	ret = cherokee_socket_write (sock, downloader->request_header, &writed);
+	ret = cherokee_socket_write (sock, &downloader->request_header, &writed);
 	switch (ret) {
 	case ret_ok:
 		/* Drop the header that has been sent
 		 */
-		cherokee_buffer_drop_endding (downloader->request_header, writed);
-		if (cherokee_buffer_is_empty (downloader->request_header)) {
+		cherokee_buffer_drop_endding (&downloader->request_header, writed);
+		if (cherokee_buffer_is_empty (&downloader->request_header)) {
 			return ret_ok;
 		}
 
@@ -251,7 +286,7 @@ downloader_header_read (cherokee_downloader_t *downloader)
 
 	sock = downloader->socket;
 	
-	ret = cherokee_socket_read (sock, downloader->reply_header, DEFAULT_RECV_SIZE, &readed);
+	ret = cherokee_socket_read (sock, &downloader->reply_header, DEFAULT_RECV_SIZE, &readed);
 	switch (ret) {
 	case ret_eof:     
 		return ret_eof;
@@ -275,7 +310,7 @@ downloader_header_read (cherokee_downloader_t *downloader)
 
 		/* Check the header. Is it complete? 
 		 */
-		ret = cherokee_header_has_header (downloader->header, downloader->reply_header, readed+4);
+		ret = cherokee_header_has_header (downloader->header, &downloader->reply_header, readed+4);
 
 		if (ret != ret_ok) {
 			/* It needs to read more header..
@@ -286,7 +321,7 @@ downloader_header_read (cherokee_downloader_t *downloader)
 		/* Parse the header
 		 */
 		ret = cherokee_header_parse (downloader->header,
-					     downloader->reply_header,
+					     &downloader->reply_header,
 					     header_type_response);		
 		if (unlikely(ret != ret_ok)) return ret_error;
 
@@ -296,15 +331,15 @@ downloader_header_read (cherokee_downloader_t *downloader)
 
 		/* Maybe it has some body
 		 */
-		if (downloader->reply_header->len > len) {
+		if (downloader->reply_header.len > len) {
 			uint32_t body_chunk;
 			
-			body_chunk = downloader->reply_header->len - len;
+			body_chunk = downloader->reply_header.len - len;
 			
 			downloader->info.body_recv += body_chunk;
-			cherokee_buffer_add (downloader->body, downloader->reply_header->buf + len, body_chunk);
+			cherokee_buffer_add (&downloader->body, downloader->reply_header.buf + len, body_chunk);
 
-			cherokee_buffer_drop_endding (downloader->reply_header, body_chunk);
+			cherokee_buffer_drop_endding (&downloader->reply_header, body_chunk);
 		}
 
 		/* Try to read the "Content-length" response header
@@ -353,7 +388,7 @@ downloader_step (cherokee_downloader_t *downloader)
 
 	sock = downloader->socket;
 
-	ret = cherokee_socket_read (sock, downloader->body, DEFAULT_RECV_SIZE, &readed);
+	ret = cherokee_socket_read (sock, &downloader->body, DEFAULT_RECV_SIZE, &readed);
 	switch (ret) {
 	case ret_eagain:
 		return ret_eagain;
