@@ -53,7 +53,7 @@
 #include "header-protected.h"
 
 
-cherokee_module_info_t cherokee_cgi_info = {
+cherokee_module_info_t MODULE_INFO(cgi)= {
 	cherokee_handler,           /* type     */
 	cherokee_handler_cgi_new    /* new func */
 };
@@ -609,6 +609,12 @@ cherokee_handler_cgi_init (cherokee_handler_cgi_t *cgi)
 		conn->error_code = http_internal_error;
 		return ret_error;
 	}
+	
+	/* It has to update the timeout of the connection,
+	 * otherwhise the server will drop it for the CGI
+	 * isn't fast enough
+	 */
+	conn->timeout = CONN_THREAD(conn)->bogo_now + CGI_TIMEOUT;
 
 	/* .. and fork the process 
 	 */
@@ -770,18 +776,7 @@ _read_from_cgi (cherokee_handler_cgi_t *cgi, cherokee_buffer_t *buffer)
 
 	switch (ret) {
 	case ret_eagain:
-		if (cgi->cgi_fd_in_poll == false) {
-			/* Add the CGI pipe file descriptor to the thread's poll
-			 */
-			ret = cherokee_fdpoll_add (HANDLER_THREAD(cgi)->fdpoll, cgi->pipeInput, 0);
-			if (unlikely(ret != ret_ok)) return ret;
-	
-			dbg ("CGI: _read_from_cgi - added fd=%d al poll\n", cgi->pipeInput);		
-			cgi->cgi_fd_in_poll = true;
-		}
-
-		ret = cherokee_thread_deactive_to_polling (HANDLER_THREAD(cgi), HANDLER_CONN(cgi), cgi->pipeInput);
-		if (unlikely(ret != ret_ok)) return ret;	
+		cherokee_thread_deactive_to_polling (HANDLER_THREAD(cgi), HANDLER_CONN(cgi), cgi->pipeInput, 0);
 		return ret_eagain;
 
 	case ret_ok:
@@ -931,15 +926,10 @@ child_finished(int sng)
 }
 #endif
 
-
-
 void
-cgi_init ()
+MODULE_INIT(cgi) (cherokee_module_loader_t *loader)
 {
-	if (_cgi_is_init == true) {
-		return;
-	}
-
+	if (_cgi_is_init) return;
 	_cgi_is_init = true;
 
 #if 0
