@@ -55,7 +55,7 @@
 #include "list_ext.h"
 
 
-cherokee_module_info_t cherokee_common_info = {
+cherokee_module_info_t MODULE_INFO(common) = {
 	cherokee_handler,              /* type     */
 	cherokee_handler_common_new    /* new func */
 };
@@ -253,17 +253,14 @@ cherokee_handler_common_new (cherokee_handler_t **hdl, void *cnt, cherokee_table
 static cherokee_boolean_t _common_is_init = false;
 
 void
-common_init (cherokee_module_loader_t *loader)
+MODULE_INIT(common) (cherokee_module_loader_t *loader)
 {
-	if (_common_is_init) {
-		return;
-	}
+	if (_common_is_init) return;
+	_common_is_init = true;
 
 	/* Load the dependences
 	 */
 	cherokee_module_loader_load (loader, "file");
 	cherokee_module_loader_load (loader, "phpcgi");
 	cherokee_module_loader_load (loader, "dirlist");
-
-	_common_is_init = true;
 }
