@@ -44,7 +44,7 @@
 #include "icons.h"
 
 
-cherokee_module_info_t cherokee_dirlist_info = {
+cherokee_module_info_t MODULE_INFO(dirlist) = {
 	cherokee_handler,               /* type     */
 	cherokee_handler_dirlist_new    /* new func */
 };
@@ -373,7 +373,7 @@ build_file_list (cherokee_handler_dirlist_t *dhdl)
 		file_entry_t *item;
 
 		item = new_file_entry(conn->local_directory, entry);
-		if (unlikely(item == NULL)) return ret_error;
+		if (unlikely(item == NULL)) continue;
 
 		if (S_ISDIR(item->stat.st_mode)) {
 			list_add ((list_t *)item, &dhdl->dirs);
@@ -737,6 +737,6 @@ cherokee_handler_dirlist_add_headers (cherokee_handler_dirlist_t *dhdl, cherokee
 /* Library init function
  */
 void
-dirlist_init (cherokee_module_loader_t *loader)
+MODULE_INIT(dirlist) (cherokee_module_loader_t *loader)
 {
 }
