@@ -56,7 +56,7 @@
 #define DEFAULT_PHP_EXECUTABLE "/usr/lib/cgi-bin/php4"
 
 
-cherokee_module_info_t cherokee_phpcgi_info = {
+cherokee_module_info_t MODULE_INFO(phpcgi) = {
 	cherokee_handler,           /* type     */
 	cherokee_handler_phpcgi_new /* new func */
 };
@@ -162,7 +162,7 @@ cherokee_handler_phpcgi_init (cherokee_handler_t *hdl)
 static cherokee_boolean_t _phpcgi_is_init = false;
 
 void
-phpcgi_init (cherokee_module_loader_t *loader)
+MODULE_INIT(phpcgi) (cherokee_module_loader_t *loader)
 {
 	/* Is init?
 	 */
