@@ -36,7 +36,7 @@
 #include "server-protected.h"
 #include "module_loader-protected.h"
 
-cherokee_module_info_t cherokee_server_info_info = {
+cherokee_module_info_t MODULE_INFO(server_info) = {
 	cherokee_handler,                /* type     */
 	cherokee_handler_server_info_new /* new func */
 };
@@ -445,3 +445,17 @@ cherokee_handler_server_info_add_headers (cherokee_handler_server_info_t *hdl, c
 
 	return ret_ok;
 }
+
+
+/* Library init function
+ */
+static cherokee_boolean_t _server_info_is_init = false;
+
+void
+MODULE_INIT(server_info) (cherokee_module_loader_t *loader)
+{
+	/* Is init?
+	 */
+	if (_server_info_is_init) return;
+	_server_info_is_init = true;
+}
