@@ -52,11 +52,11 @@
 
 
 
-const struct {
+static struct {
 	char *name;
 	int   len;
 } 
-known_headers_names [] = {
+known_header_names [] = {
 	{"Connection",      10},
 	{"Content-Range",   13},
 	{"Keep-Alive",      10},
@@ -367,11 +367,19 @@ get_new_line (char *string)
 {
 	char *end1;
 	char *end2;
+	char *farest;
 
-	end1 = strchr (string, '\r');
-	end2 = strchr (string, '\n');
+	do {
+		end1 = strchr (string, '\r');
+		end2 = strchr (string, '\n');
 
-	return cherokee_min_str (end1, end2);
+		farest = cherokee_min_str (end1, end2);
+		if (farest == NULL) return NULL;
+
+		string = farest+1;
+	} while (farest[1] == ' ');
+
+	return farest;
 }
 
 ret_t 
@@ -530,7 +538,7 @@ cherokee_header_parse (cherokee_header_t *hdr, cherokee_buffer_t *buffer,  chero
 
 
 ret_t 
-cherokee_header_get_length (cherokee_header_t *hdr, uint32_t *len)
+cherokee_header_get_length (cherokee_header_t *hdr, cuint_t *len)
 {
 	*len = hdr->input_header_len;
 	return ret_ok;
@@ -766,8 +774,8 @@ cherokee_header_foreach (cherokee_header_t *hdr, cherokee_header_foreach_func_t
 	for (i=0; i<HEADER_LENGTH; i++)
 	{
 		if (hdr->header[i].info_off != 0) {
-			header_name = known_headers_names[i].name;
-			header_len  = known_headers_names[i].len;
+			header_name = known_header_names[i].name;
+			header_len  = known_header_names[i].len;
 
 			cherokee_buffer_clean (name);
 			cherokee_buffer_clean (cont);
