@@ -61,7 +61,7 @@ static char *month[] = {
 };
 
 
-cherokee_module_info_t cherokee_ncsa_info = {
+cherokee_module_info_t MODULE_INFO(ncsa) = {
 	cherokee_logger,            /* type     */
 	cherokee_logger_ncsa_new    /* new func */
 };
@@ -368,17 +368,15 @@ cherokee_logger_ncsa_write_error (cherokee_logger_ncsa_t *logger, cherokee_conne
 /*   Library init function
  */
 
-static int _ncsa_is_init = 0;
+static cherokee_boolean_t _ncsa_is_init = false;
 
 void
-ncsa_init ()
+MODULE_INIT(ncsa) (cherokee_module_loader_t *loader)
 {
 	/* Init flag
 	 */
-	if (_ncsa_is_init) {
-		return;
-	}
-	_ncsa_is_init = 1;
+	if (_ncsa_is_init) return;
+	_ncsa_is_init = true;
 }
 
 
