@@ -193,7 +193,7 @@ dylib_open (const char *libname, void **handler_out)
 	 */
 	lib = dlopen (tmp->buf, flags);
 	if (lib == NULL) {
-		PRINT_ERROR ("ERROR: dlopen(): %s\n", dlerror());
+		PRINT_ERROR ("ERROR: dlopen(%s): %s\n", tmp->buf, dlerror());
 		goto error;
 	}
 
