@@ -52,6 +52,7 @@
 #include "module_loader.h"
 #include "icons.h"
 #include "mmap2.h"
+#include "regex.h"
 
 struct cherokee_server {
 	/* Current time
@@ -66,8 +67,8 @@ struct cherokee_server {
 
 	/* Exit related
 	 */
-	char *panic_action;
-	int   wanna_exit;
+	char  *panic_action;
+	int    wanna_exit;
 	
 	/* Virtual servers
 	 */
@@ -77,22 +78,23 @@ struct cherokee_server {
 	
 	/* Threads
 	 */
-	cherokee_thread_t *main_thread;
-	int                thread_num;
-	struct list_head   thread_list;
-	int                thread_policy;
+	cherokee_thread_t         *main_thread;
+	int                        thread_num;
+	struct list_head           thread_list;
+	int                        thread_policy;
 
 	/* Modules
 	 */
-	cherokee_logger_table_t  *loggers;
-	cherokee_module_loader_t *loader;
-	cherokee_encoder_table_t *encoders;
+	cherokee_logger_table_t   *loggers;
+	cherokee_module_loader_t  *loader;
+	cherokee_encoder_table_t  *encoders;
 
 	/* Tables: icons, mmap
 	 */
-	cherokee_icons_t *icons;
-	cherokee_mmap2_t *mmap_cache;
-	time_t            mmap_cache_clean_next;
+	cherokee_icons_t          *icons;
+	cherokee_regex_table_t    *regexs;
+	cherokee_mmap2_t          *mmap_cache;
+	time_t                     mmap_cache_clean_next;
 
 	/* Default index files
 	 */
@@ -105,8 +107,10 @@ struct cherokee_server {
 
 	/* Main socket
 	 */
-	int socket;
-	int socket_tls;
+	int                  socket;
+	int                  socket_tls;
+	cherokee_poll_type_t fdpoll_method;
+
 
 #ifdef HAVE_PTHREAD
 	pthread_mutex_t accept_mutex;
