@@ -76,6 +76,7 @@
 #include "util.h"
 #include "fdpoll.h"
 #include "fdpoll-protected.h"
+#include "regex.h"
 
 
 static ret_t init_tls_library          (void);
@@ -114,6 +115,7 @@ cherokee_server_new  (cherokee_server_t **srv)
 	n->socket          = -1;
 	n->socket_tls      = -1;
 	n->ipv6            =  1;
+	n->fdpoll_method   = cherokee_poll_UNSET;
 
 	/* Config files
 	 */
@@ -162,6 +164,10 @@ cherokee_server_new  (cherokee_server_t **srv)
 	n->sendfile.min    = 32768;
 	n->sendfile.max    = 2147483647;
 
+	n->regexs          = NULL;
+	n->icons           = NULL;
+	n->mmap_cache      = NULL;
+
 	/* Time managing hack
 	 */
 	cherokee_buffer_new (&n->timeout_header);
@@ -194,6 +200,11 @@ cherokee_server_new  (cherokee_server_t **srv)
 	cherokee_mmap2_new (&n->mmap_cache);
 	return_if_fail (n->mmap_cache != NULL, ret_nomem);	
 	n->mmap_cache_clean_next = 0;
+
+	/* Regexs
+	 */
+	cherokee_regex_table_new (&n->regexs);
+	return_if_fail (n->regexs != NULL, ret_nomem);	
 #endif
 
 	/* Module loader
@@ -328,6 +339,10 @@ cherokee_server_clean (cherokee_server_t *srv)
 		free (srv->mime_file);
 		srv->mime_file = NULL;
 	}
+
+	/* Regex cache
+	 */
+	cherokee_regex_table_clean (srv->regexs);
 #endif
 
 	/* Clean the encoders table
@@ -411,6 +426,7 @@ cherokee_server_free (cherokee_server_t *srv)
 	}
 
 	cherokee_mmap2_free (srv->mmap_cache);
+	cherokee_regex_table_free (srv->regexs);
 #endif
 	
 	/* Module loader
@@ -712,9 +728,9 @@ print_banner (cherokee_server_t *srv)
 	 */
 	if (srv->tls_enabled) {
 #if defined(HAVE_GNUTLS)
-		cherokee_buffer_add (n, ", with TLS support via GNUTLS", 30);
+		cherokee_buffer_add (n, ", with TLS support via GNUTLS", 29);
 #elif defined(HAVE_OPENSSL)
-		cherokee_buffer_add (n, ", with TLS support via OpenSSL", 31);
+		cherokee_buffer_add (n, ", with TLS support via OpenSSL", 30);
 #endif
 	} else {
 		cherokee_buffer_add (n, ", TLS disabled", 14);		
@@ -833,7 +849,7 @@ initialize_server_threads (cherokee_server_t *srv)
 	/* Create the main thread
 	 */
 	ret = cherokee_thread_new (&srv->main_thread, srv, thread_sync, 
-				   srv->system_fd_limit, fds_per_thread);
+				   srv->fdpoll_method, srv->system_fd_limit, fds_per_thread);
 	if (unlikely(ret < ret_ok)) return ret;
 
 	/* If Cherokee is compiled in single thread mode, it has to
@@ -857,7 +873,7 @@ initialize_server_threads (cherokee_server_t *srv)
 		cherokee_thread_t *thread;
 
 		ret = cherokee_thread_new (&thread, srv, thread_async, 
-					   srv->system_fd_limit, fds_per_thread);
+					   srv->fdpoll_method, srv->system_fd_limit, fds_per_thread);
 		if (unlikely(ret < ret_ok)) return ret;
 		
 		thread->thread_pref = (i % 2)? thread_normal_tls : thread_tls_normal;
@@ -1112,14 +1128,13 @@ cherokee_server_reinit (cherokee_server_t *srv)
 	ret_t  ret;
 	
 	if (srv->chrooted) {
-		fprintf (stderr, 
-			 "WARNING: Chrooted cherokee cannot be reloaded. "
-			 "Please, stop and restart it again.\n");
+		PRINT_ERROR_S ("WARNING: Chrooted cherokee cannot be reloaded. "
+			       "Please, stop and restart it again.\n");
 		return ret_ok;
 	}
 
 
-#if 1
+#if 0
 	{
 		int tmp;
 		printf ("Handling server reinit. Press any key to continue..\n");
@@ -1149,22 +1164,22 @@ cherokee_server_reinit (cherokee_server_t *srv)
 static void
 update_bogo_now (cherokee_server_t *srv)
 {
-	static unsigned char to_wait = 1;
-	int unlocked;
+	time_t prev;
 
-	unlocked = CHEROKEE_RWLOCK_TRYWRITER (&srv->bogo_now_mutex);     /* 1.- lock as writer */
-	if (unlocked) return;
+	CHEROKEE_RWLOCK_WRITER (&srv->bogo_now_mutex);      /* 1.- lock as writer */
 
+	prev = srv->bogo_now;
 	srv->bogo_now = time (NULL);
 	cherokee_gmtime (&srv->bogo_now, &srv->bogo_now_tm);
 	
-	if (--to_wait == 0) {
+	/* Update time string if needed
+	 */
+	if (prev < srv->bogo_now) {
 		srv->bogo_now_string->len = strftime (srv->bogo_now_string->buf, srv->bogo_now_string->size,
 						      "%a, %d %b %Y %H:%M:%S GMT", &srv->bogo_now_tm);
-		to_wait = 1000 / srv->fdwatch_msecs;
 	}
 
-	CHEROKEE_RWLOCK_UNLOCK (&srv->bogo_now_mutex);                   /* 2.- release */
+	CHEROKEE_RWLOCK_UNLOCK (&srv->bogo_now_mutex);      /* 2.- release */
 }
 
 
