@@ -5,9 +5,8 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * This piece of code by:
+ * Some patches by:
  *      Ricardo Cardenes Medina <ricardo@conysis.com>
- *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
  * Copyright (C) 2001, 2002, 2003, 2004, 2005 Alvaro Lopez Ortega
  *
@@ -63,7 +62,10 @@
 
 /* sendfile() function related includes
  */
-#if defined(LINUX_SENDFILE_API) || defined(SOLARIS_SENDFILE_API)
+#if defined(LINUX_SENDFILE_API) 
+# include <sys/sendfile.h>
+
+#elif defined(SOLARIS_SENDFILE_API)
 # include <sys/sendfile.h>
 
 #elif defined(HPUX_SENDFILE_API)
@@ -443,9 +445,11 @@ cherokee_socket_pton (cherokee_socket_t *socket, cherokee_buffer_t *host)
 		r = inet_pton (AF_INET6, host->buf, &SOCKET_SIN_ADDR(socket));
 	} else 
 #endif
-	{
+#ifdef HAVE_INET_PTON
 		r = inet_pton (AF_INET, host->buf, &SOCKET_SIN_ADDR(socket));
-	}
+#else		
+	        r = inet_aton (host->buf, &SOCKET_SIN_ADDR(socket));
+#endif
 
 	return (r > 0) ? ret_ok : ret_error;
 }
@@ -496,13 +500,14 @@ cherokee_socket_set_sockaddr (cherokee_socket_t *socket, int fd, struct sockaddr
 ret_t
 cherokee_socket_accept_fd (int server_socket, int *new_fd, struct sockaddr *sa)
 {
-	int tmp = 1;
-	int new_socket;
+	socklen_t len;
+	int       new_socket;
+	int       tmp = 1;
 
 	/* Get the new connection
 	 */
-	tmp = sizeof (struct sockaddr);
-	new_socket = accept (server_socket, sa, &tmp);
+	len = sizeof (struct sockaddr);
+	new_socket = accept (server_socket, sa, &len);
 	if (new_socket <= 0) {
 		return ret_error;
 	}		
@@ -920,23 +925,44 @@ cherokee_socket_sendfile (cherokee_socket_t *socket, int fd, size_t size, off_t
 	}
 	*offset = *offset + *sent;
 
-# else
+# elif SOLARIS_SENDFILE_API
+
+	/* TODO!!
+	 */
+	return ret_no_sys;
+
+# elif HAVE_SENDFILE_BROKEN
+
+	/* Some Linux 2.4 kernels doesn't support sendfile in a LFS environment
+	 */
+	return ret_no_sys;
+
+# elif LINUX_SENDFILE_API
+
 	/* Linux sendfile
 	 *
 	 * ssize_t 
 	 * sendfile (int out_fd, int in_fd, off_t *offset, size_t *count);
 	 */
-	*sent = sendfile (SOCKET_FD(socket),              /* int     out_fd */
-			  fd,                             /* int     in_fd  */
-			  offset,                         /* off_t  *offset */
-			  size);                          /* size_t  count  */
-
-	if (*sent < 0) {
-		if (errno == EAGAIN) 
-			return ret_eagain;
+	do {
+		*sent = sendfile (SOCKET_FD(socket),            /* int     out_fd */
+				  fd,                           /* int     in_fd  */
+				  offset,                       /* off_t  *offset */
+				  size);                        /* size_t  count  */
+	} while ((*sent == -1) && (errno == EINTR));
 		
+	if (*sent < 0) {
+		switch (errno) {
+		case ENOSYS: return ret_no_sys;
+		case EAGAIN: return ret_eagain;
+		}
+
 		return ret_error;
 	}
+
+# else
+	SHOULDNT_HAPPEN;
+	return ret_no_sys;
 # endif
 
 	return ret_ok;
