@@ -70,7 +70,11 @@
 #ifdef INET6_ADDRSTRLEN
 # define CHE_INET_ADDRSTRLEN INET6_ADDRSTRLEN
 #else
-# define CHE_INET_ADDRSTRLEN INET_ADDRSTRLEN
+#  ifdef INET_ADDRSTRLEN
+#    define CHE_INET_ADDRSTRLEN INET_ADDRSTRLEN
+#  else
+#    define CHE_INET_ADDRSTRLEN 16
+#  endif
 #endif
 
 
