@@ -44,10 +44,14 @@
 
 
 static void
-update_bogo_now (cherokee_thread_t *thd)
+update_bogo_now_internal (cherokee_thread_t *thd)
 {
 	cherokee_server_t *srv = THREAD_SRV(thd);
 
+	/* Has it changed?
+	 */
+	if (thd->bogo_now == srv->bogo_now) return;
+
 	/* Update time_t
 	 */
 	thd->bogo_now = srv->bogo_now;
@@ -64,6 +68,14 @@ update_bogo_now (cherokee_thread_t *thd)
 }
 
 
+static void
+update_bogo_now (cherokee_thread_t *thd)
+{
+	CHEROKEE_RWLOCK_READER (&THREAD_SRV(thd)->bogo_now_mutex);
+	update_bogo_now_internal(thd);
+	CHEROKEE_RWLOCK_UNLOCK (&THREAD_SRV(thd)->bogo_now_mutex);
+}
+
 static void
 try_to_update_bogo_now (cherokee_thread_t *thd)
 {
@@ -75,7 +87,7 @@ try_to_update_bogo_now (cherokee_thread_t *thd)
 	unlocked = CHEROKEE_RWLOCK_TRYREADER (&srv->bogo_now_mutex);        /* 1.- lock a reader */
 	if (unlocked) return;
 
-	update_bogo_now (thd);
+	update_bogo_now_internal (thd);
 
 	CHEROKEE_RWLOCK_UNLOCK (&srv->bogo_now_mutex);                      /* 2.- release */
 }
@@ -118,7 +130,7 @@ cherokee_thread_unlock (cherokee_thread_t *thd)
 
 ret_t 
 cherokee_thread_new  (cherokee_thread_t **thd, void *server, cherokee_thread_type_t type, 
-		      int system_fd_num, int fd_num)
+		      cherokee_poll_type_t fdpoll_type, int system_fd_num, int fd_num)
 {
 	cherokee_server_t *srv = SRV(server);
 	CHEROKEE_NEW_STRUCT (n, thread);
@@ -130,7 +142,10 @@ cherokee_thread_new  (cherokee_thread_t **thd, void *server, cherokee_thread_typ
 	INIT_LIST_HEAD((list_t*)&n->reuse_list);
 	INIT_LIST_HEAD((list_t*)&n->polling_list);
 	
-	cherokee_fdpoll_best_new (&n->fdpoll, system_fd_num, fd_num);
+	if (fdpoll_type == cherokee_poll_UNSET)
+		cherokee_fdpoll_best_new (&n->fdpoll, system_fd_num, fd_num);
+	else
+		cherokee_fdpoll_new (&n->fdpoll, fdpoll_type, system_fd_num, fd_num);
 
 	n->active_list_num   = 0;
 	n->polling_list_num  = 0;
@@ -252,16 +267,8 @@ connection_reuse_or_free (cherokee_thread_t *thread, cherokee_connection_t *conn
 
 
 static void
-purge_closed_connection (cherokee_thread_t *thread, cherokee_connection_t *conn)
+purge_connection (cherokee_thread_t *thread, cherokee_connection_t *conn)
 {
-	/* Delete from file descriptors poll
-	 */
-	cherokee_fdpoll_del (thread->fdpoll, SOCKET_FD(conn->socket));
-
-	/* Delete from active connections list
-	 */
-	del_connection (thread, conn);
-
 	/* Maybe have a delayed log
 	 */
 	cherokee_connection_log_delayed (conn);
@@ -276,6 +283,41 @@ purge_closed_connection (cherokee_thread_t *thread, cherokee_connection_t *conn)
 }
 
 
+static void
+purge_closed_polling_connection (cherokee_thread_t *thread, cherokee_connection_t *conn)
+{
+	/* Delete from file descriptors poll
+	 */
+	cherokee_fdpoll_del (thread->fdpoll, conn->extra_polling_fd);
+
+	/* Remove from the polling list
+	 */
+	del_connection_polling (thread, conn);
+	
+	/* The connection hasn't the main fd in the file descriptor poll
+	 * so, we just have to remove the connection.
+	 */
+	purge_connection (thread, conn);
+}
+
+
+static void
+purge_closed_connection (cherokee_thread_t *thread, cherokee_connection_t *conn)
+{
+	/* Delete from file descriptors poll
+	 */
+	cherokee_fdpoll_del (thread->fdpoll, SOCKET_FD(conn->socket));
+
+	/* Remove from active connections list
+	 */
+	del_connection (thread, conn);
+
+	/* Finally, purge connection
+	 */
+	purge_connection (thread, conn);
+}
+
+
 static void
 maybe_purge_closed_connection (cherokee_thread_t *thread, cherokee_connection_t *conn)
 {
@@ -324,7 +366,7 @@ process_polling_connections (cherokee_thread_t *thd)
 		/* May the connection was too much time w/o any work
 		 */
 		if (conn->timeout < thd->bogo_now) {
-			purge_closed_connection (thd, conn);
+			purge_closed_polling_connection (thd, conn);
 			continue;
 		}
 		
@@ -1104,6 +1146,14 @@ step_MULTI_THREAD_block (cherokee_thread_t *thd, int socket, pthread_mutex_t *mu
 	cherokee_fdpoll_reset (thd->fdpoll, socket);
 	cherokee_fdpoll_watch (thd->fdpoll, fdwatch_msecs);
 	
+	/* This thread might been blocked for long long time,
+	 * so it's really important to update the local bogo now
+	 * values before accept new connections.  Otherwhise, it
+	 * will use an old value for the new connections timeout
+	 * and it'll drop it out in the next step.
+	 */
+	update_bogo_now (thd);
+
 	do {
 		re = __accept_from_server (thd, socket, non_TLS);
 	} while (__should_accept_more_from_server (thd, re));
@@ -1281,6 +1331,11 @@ step_MULTI_THREAD_TLS_block (cherokee_thread_t *thd, int fdwatch_msecs,
 	/* Inspect the fds and get new connections
 	 */
 	cherokee_fdpoll_watch (thd->fdpoll, fdwatch_msecs);
+
+	/* Update the thread time values before accept new connections.
+	 * This ensure a good timeout value for it.
+	 */
+	update_bogo_now (thd);
 		
 	do {
 		re = __accept_from_server (thd, socket1, type1);
@@ -1314,6 +1369,10 @@ cherokee_thread_step_MULTI_THREAD (cherokee_thread_t *thd, cherokee_boolean_t do
 	cherokee_server_t *srv           = THREAD_SRV(thd);
 	int                fdwatch_msecs = srv->fdwatch_msecs;
 
+	/* Try to update bogo_now
+	 */
+	try_to_update_bogo_now (thd);
+
 	/* If the thread is full of connections, it should not
 	 * get new connections
 	 */
@@ -1358,10 +1417,6 @@ cherokee_thread_step_MULTI_THREAD (cherokee_thread_t *thd, cherokee_boolean_t do
 	}
 	
 out:
-	/* Try to update bogo_now
-	 */
-	try_to_update_bogo_now (thd);
-
 	/* Process polling connections
 	 */
 	process_polling_connections (thd);
@@ -1452,12 +1507,20 @@ cherokee_thread_close_all_connections (cherokee_thread_t *thd)
  */
 
 ret_t 
-cherokee_thread_deactive_to_polling (cherokee_thread_t *thd, cherokee_connection_t *conn, int fd)
+cherokee_thread_deactive_to_polling (cherokee_thread_t *thd, cherokee_connection_t *conn, int fd, int rw)
 {	
 	cherokee_socket_t *socket = CONN_SOCK(conn);
 
+	/* Set the information in the connection
+	 */
+	conn->extra_polling_fd = fd;
+
+	/* Remove the connection file descriptor and add the new one
+	 */
 	cherokee_fdpoll_del (thd->fdpoll, SOCKET_FD(socket));
-	return cherokee_thread_move_connection_to_polling (thd, conn, fd);
+	cherokee_fdpoll_add (thd->fdpoll, fd, rw);
+
+	return cherokee_thread_move_connection_to_polling (thd, conn);
 }
 
 ret_t 
@@ -1465,23 +1528,25 @@ cherokee_thread_reactive_from_polling (cherokee_thread_t *thd, cherokee_connecti
 {	
 	cherokee_socket_t *socket = CONN_SOCK(conn);
 
+	/* Set the connection file descriptor and remove the old one
+	 */
+	cherokee_fdpoll_del (thd->fdpoll, conn->extra_polling_fd);
 	cherokee_fdpoll_add (thd->fdpoll, socket->socket, socket->status);
+
+	/* Remove the polling fd from the connection
+	 */
+	conn->extra_polling_fd = -1;
+
 	return cherokee_thread_move_connection_to_active (thd, conn);
 }
 
 
 ret_t 
-cherokee_thread_move_connection_to_polling (cherokee_thread_t *thd, cherokee_connection_t *conn, int fd)
+cherokee_thread_move_connection_to_polling (cherokee_thread_t *thd, cherokee_connection_t *conn)
 {
-	/* Set the information in the connection
-	 */
-	conn->extra_polling_fd = fd;
-
-	/* Move from 'active' to 'polling'
-	 */
 	del_connection (thd, conn);
-	add_connection_polling (thd, conn);
-	
+	add_connection_polling (thd, conn);	
+
 	return ret_ok;
 }
 
@@ -1489,12 +1554,6 @@ cherokee_thread_move_connection_to_polling (cherokee_thread_t *thd, cherokee_con
 ret_t 
 cherokee_thread_move_connection_to_active (cherokee_thread_t *thd, cherokee_connection_t *conn)
 {
-	/* Remove the polling fd from the connection
-	 */
-	conn->extra_polling_fd = -1;
-
-	/* Move from 'active' to 'polling'
-	 */
 	del_connection_polling (thd, conn);
 	add_connection (thd, conn);
 
