@@ -54,9 +54,11 @@ cherokee_url_new  (cherokee_url_t **url)
 }
 
 
-ret_t 
-cherokee_url_free (cherokee_url_t *url)
+ret_t
+cherokee_url_clean (cherokee_url_t *url)
 {
+	url->port = 80;
+
 	if (url->host != NULL) {
 		cherokee_buffer_free (url->host);
 		url->host = NULL;
@@ -66,7 +68,16 @@ cherokee_url_free (cherokee_url_t *url)
 		cherokee_buffer_free (url->request);
 		url->request = NULL;
 	}
-	
+
+	return ret_ok;
+}
+
+
+ret_t 
+cherokee_url_free (cherokee_url_t *url)
+{
+	cherokee_url_clean (url);
+
 	free (url);
 	return ret_ok;
 }
