@@ -48,8 +48,8 @@ struct tm *cherokee_gmtime (const time_t *timep, struct tm *result);
 
 /* Misc
  */
-ret_t cherokee_sys_fdlimit_get (uint32_t *limit);
-ret_t cherokee_sys_fdlimit_set (uint32_t  limit);
+ret_t cherokee_sys_fdlimit_get (cuint_t *limit);
+ret_t cherokee_sys_fdlimit_set (cuint_t  limit);
 
 
 /* Path walking
