@@ -46,7 +46,9 @@ cherokee_virtual_server_new (cherokee_virtual_server_t **vserver)
 
 	vsrv->data.rx       = 0;
 	vsrv->data.tx       = 0;
-	
+	CHEROKEE_MUTEX_INIT(&vsrv->data.rx_mutex, NULL);
+	CHEROKEE_MUTEX_INIT(&vsrv->data.tx_mutex, NULL);
+
 	vsrv->server_cert  = NULL;
 	vsrv->server_key   = NULL;
 	vsrv->ca_cert      = NULL;
