@@ -21,7 +21,9 @@ clean    = True
 kill     = True
 quiet    = False
 valgrind = False
+strace   = False
 port     = None
+method   = None
 server   = CHEROKEE_PATH
 
 # Make the DocumentRoot directory
@@ -44,16 +46,18 @@ if len(files) == 0:
 
 # Process the parameters
 for p in param:
-    if   p == '-d': pause    = True
-    elif p == '-c': clean    = False
-    elif p == '-k': kill     = False
-    elif p == '-q': quiet    = True
-    elif p == '-v': valgrind = True
-    elif p == '-s': ssl      = True
-    elif p[:2] == '-n': num    = int(p[2:])
-    elif p[:2] == '-t': thds   = int(p[2:])
-    elif p[:2] == '-p': port   = int(p[2:])
-    elif p[:2] == '-e': server = p[2:]
+    if   p     == '-d': pause    = True
+    elif p     == '-c': clean    = False
+    elif p     == '-k': kill     = False
+    elif p     == '-q': quiet    = True
+    elif p     == '-v': valgrind = True
+    elif p     == '-s': ssl      = True
+    elif p     == '-x': strace   = True
+    elif p[:2] == '-n': num      = int(p[2:])
+    elif p[:2] == '-t': thds     = int(p[2:])
+    elif p[:2] == '-p': port     = int(p[2:])
+    elif p[:2] == '-m': method   = p[2:]
+    elif p[:2] == '-e': server   = p[2:]
 
 # Configuration file base
 CONF_BASE = """# Cherokee QA tests
@@ -72,6 +76,10 @@ if ssl:
                    SSLCAListFile         %s
                  """ % (SSL_CERT_FILE, SSL_CERT_KEY_FILE, SSL_CA_FILE)
 
+if method:
+    CONF_BASE += """ PollMethod %s
+                 """ % (method)
+
 # Import modules 
 mods = []
 for f in files:
@@ -107,7 +115,9 @@ if port is None:
     pid = os.fork()
     if pid == 0:
         if valgrind:
-            os.execl (VALGRIND_PATH, "valgrind", server, "-C", cfg_file)
+            os.execl (VALGRIND_PATH, "valgrind", "--num-callers=15", server, "-C", cfg_file)
+        elif strace:
+            os.execl (STRACE_PATH, "strace", server, "-C", cfg_file)            
         else:
             name = server[server.rfind('/') + 1:]
             os.execl (server, name, "-C", cfg_file)
